@@ -104,18 +104,6 @@ class Adafruit_BME280:
         self._t_fine = int(var1 + var2)
         #print("t_fine: ", self.t_fine)
 
-    @property
-    def dew_point(self):
-        # pylint: disable=invalid-name
-        # Disable: c is a constant used in the Magnus formula
-        """The dew point in Celsius using the Magnus formula. Constants from Sontag, 1990."""
-        b = 17.62
-        c = 243.12
-        gamma = (b * self.temperature /(c + self.temperature)) + math.log(self.humidity / 100.0)
-        dewpoint = (c * gamma) / (b - gamma)
-        return dewpoint
-        # pylint: enable=invalid-name
-
     @property
     def temperature(self):
         """The compensated temperature in degrees celsius."""
@@ -210,7 +198,7 @@ class Adafruit_BME280:
         self._humidity_calib[1] = float(coeff[0])
         self._humidity_calib[2] = float(coeff[1])
         self._humidity_calib[3] = float((coeff[2] << 4) |  (coeff[3] & 0xF))
-        self._humidity_calib[4] = float(((coeff[3] & 0xF0) << 4) | coeff[4])
+        self._humidity_calib[4] = float((coeff[4] << 4) | (coeff[3] >> 4))
         self._humidity_calib[5] = float(coeff[5])
 
     def _read_byte(self, register):
